pub fn get_csv_metadata(
args: MetadataArgs<'_>,
worker_map: &BiHashMap<u32, String>,
) -> Vec<String>Expand description
Returns a vector of lines containing the metadata of the measurement
Arguments
args- Contains measurement arguments to be written into the metadataworker_map- Convert IDs to hostnames